==> ejc-zdsstore-impl-3.0.0-20240128.053759-153-sources.jar: com/ejianc/business/zdsstore/controller/api/StoreFlowApi.java <==
package com.ejianc.business.zdsstore.controller.api;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.ejianc.business.zdsstore.bean.FlowEntity;
import com.ejianc.business.zdsstore.bean.InOutEntity;
import com.ejianc.business.zdsstore.bean.SurplusEntity;
import com.ejianc.business.zdsstore.consts.StoreCommonConsts;
import com.ejianc.business.zdsstore.service.IFlowService;
import com.ejianc.business.zdsstore.service.IInOutService;
import com.ejianc.business.zdsstore.service.ISurplusService;
import com.ejianc.business.zdsstore.vo.FlowVO;
import com.ejianc.business.zdsstore.vo.InOutVO;
import com.ejianc.business.zdsstore.vo.SurplusVO;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.core.response.Parameter;
import com.ejianc.framework.core.response.QueryParam;
import com.ejianc.framework.core.util.ComputeUtil;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.apache.commons.collections.CollectionUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.ArrayList;
import java.util.List;

@RestController
@RequestMapping("/api/storeFlow/")
@Api(value = "仓库流水公共API接口", tags = {"仓库流水公共API接口"})
public class StoreFlowApi {

    private Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    IFlowService flowService;
    @Autowired
    private IInOutService inOutService;
    @Autowired
    private ISurplusService surplusService;

    /**
     * @param queryParam 参数
     * @description: 查询流水
     * @return: com.ejianc.framework.core.response.CommonResponse<java.lang.String>
     * @author songlx
     * @date: 2022/1/18
     */
    @ApiOperation("查询流水")
    @RequestMapping(value = "/getFlowList", method = RequestMethod.POST)
    @ResponseBody
    CommonResponse<List<FlowVO>> getFlowList(@RequestBody QueryParam queryParam) {
        List<FlowEntity> flowEntityList = flowService.queryList(queryParam);
        List<FlowVO> flowVOS = BeanMapper.mapList(flowEntityList, FlowVO.class);
        return CommonResponse.success(flowVOS);
    }

    /**
     * @param queryParam
     * @description: 查询出入库关系
     * @return: com.ejianc.framework.core.response.CommonResponse<com.ejianc.business.store.vo.InOutVO>
     * @author 姜轶凯
     * @date: 2022/3/15
     */
    @RequestMapping(value = "/getInOutVOList", method = RequestMethod.POST)
    @ResponseBody
    CommonResponse<List<InOutVO>> getInOutVOList(@RequestBody QueryParam queryParam){
        List<InOutEntity> inOutEntities = inOutService.queryList(queryParam);
        List<InOutVO> inOutVOS = BeanMapper.mapList(inOutEntities, InOutVO.class);
        return CommonResponse.success(inOutVOS);
    }

    @RequestMapping(value = "/getNewPrice", method = RequestMethod.POST)
    @ResponseBody
    CommonResponse<List<FlowVO>> getNewPrice(@RequestBody List<FlowVO> flowVOS){
        List<FlowVO> result = new ArrayList<>();
        for (FlowVO flowVO : flowVOS) {
            QueryWrapper<FlowEntity> wrapper = new QueryWrapper();
            wrapper.eq("store_id", flowVO.getStoreId());
            wrapper.eq("material_id", flowVO.getMaterialId());
            wrapper.eq("brand_id", flowVO.getBrandId());
            wrapper.eq("in_out_flag", StoreCommonConsts.IN_OUT_TYPE_IN);
            wrapper.orderByDesc( "source_bill_date");
            wrapper.last("limit 0,1");
            List<FlowEntity> flowEntities = flowService.list(wrapper);
            if (CollectionUtils.isNotEmpty(flowEntities)) {
                result.add(BeanMapper.map(flowEntities.get(0), FlowVO.class));
            }
        }
        return CommonResponse.success("查询最新单价成功！", result);
    }

    /**
     * 批量获取最新的库存余量
     * @param surplusVOS
     * @return
     */
    @RequestMapping(value = "/getNewSurplusNum", method = RequestMethod.POST)
    @ResponseBody
    CommonResponse<List<SurplusVO>> getNewSurplusNum(@RequestBody List<SurplusVO> surplusVOS){
        QueryWrapper<SurplusEntity> queryWrapper = new QueryWrapper<>();
        queryWrapper.and(q -> {
            for(SurplusVO f : surplusVOS) {
                q.or(iq -> iq.eq("store_id", f.getStoreId()).eq("brand_id", f.getBrandId()).eq("material_id", f.getMaterialId()));
            }
            return q;
        });
        List<SurplusEntity> list = surplusService.list(queryWrapper);
        List<SurplusVO> result = null;
        if (CollectionUtils.isNotEmpty(list)) {
            result = BeanMapper.mapList(list, SurplusVO.class);
            for (SurplusVO surplusVO : result) {
                surplusVO.setSurplusTaxPrice(ComputeUtil.safeDiv(surplusVO.getSurplusTaxMny(), surplusVO.getSurplusNum()));
                surplusVO.setSurplusPrice(ComputeUtil.safeDiv(surplusVO.getSurplusMny(), surplusVO.getSurplusNum()));
                surplusVO.setSurplusNum(ComputeUtil.safeSub(surplusVO.getSurplusNum(), surplusVO.getIdleNum()));
            }
        }
        return CommonResponse.success("批量获取最新的库存余量成功！", result);
    }

    /**
     * 根据仓库查询库存参照
     * @param storeId
     * @return
     */
    @RequestMapping(value = "/refSurplusData", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<List<SurplusVO>> refSurplusData(@RequestParam("storeId") Long storeId) {
        QueryParam param = new QueryParam();
        /** 租户隔离 */
        param.getParams().put("storeId", new Parameter(QueryParam.EQ, storeId));
        //库存可用数量大于0
        param.getParams().put("surplusNum", new Parameter(QueryParam.SQL, "(IFNULL(surplus_num,0)-IFNULL(idle_num,0))>0"));
        param.getOrderMap().clear();
        param.getOrderMap().put("abs(ifnull(surplus_num,0)-ifnull(idle_num,0))", "desc");

        List<SurplusEntity> list = surplusService.queryList(param, false);
        List<SurplusVO> surplusVOS = BeanMapper.mapList(list, SurplusVO.class);
        surplusVOS.forEach(
                t -> {
                    t.setSurplusHasOutLockNum(ComputeUtil.safeAdd(t.getSurplusNum(), t.getOutLockNum()));
                    t.setSurplusMny(ComputeUtil.safeAdd(t.getSurplusMny(), t.getOutLockMny()));
                    t.setSurplusTaxMny(ComputeUtil.safeAdd(t.getSurplusTaxMny(), t.getOutLockTaxMny()));
                    t.setSurplusNum(ComputeUtil.safeSub(t.getSurplusNum(), t.getIdleNum()));
                }
        );
        return CommonResponse.success("查询参照数据成功！", surplusVOS);
    }
}

==> ejc-zdsstore-impl-3.0.0-20240723.134736-204-sources.jar: com/ejianc/business/zdsstore/controller/api/StoreFlowApi.java <==
package com.ejianc.business.zdsstore.controller.api;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ejianc.business.zdsstore.bean.FlowEntity;
import com.ejianc.business.zdsstore.bean.InOutEntity;
import com.ejianc.business.zdsstore.bean.SurplusEntity;
import com.ejianc.business.zdsstore.consts.StoreCommonConsts;
import com.ejianc.business.zdsstore.service.IFlowService;
import com.ejianc.business.zdsstore.service.IInOutService;
import com.ejianc.business.zdsstore.service.ISurplusService;
import com.ejianc.business.zdsstore.vo.FlowVO;
import com.ejianc.business.zdsstore.vo.InOutVO;
import com.ejianc.business.zdsstore.vo.SurplusVO;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.core.response.Parameter;
import com.ejianc.framework.core.response.QueryParam;
import com.ejianc.framework.core.util.ComputeUtil;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.apache.commons.collections.CollectionUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.ArrayList;
import java.util.List;

@RestController
@RequestMapping("/api/storeFlow/")
@Api(value = "仓库流水公共API接口", tags = {"仓库流水公共API接口"})
public class StoreFlowApi {

    private Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    IFlowService flowService;
    @Autowired
    private IInOutService inOutService;
    @Autowired
    private ISurplusService surplusService;

    /**
     * @param queryParam 参数
     * @description: 查询流水
     * @return: com.ejianc.framework.core.response.CommonResponse<java.lang.String>
     * @author songlx
     * @date: 2022/1/18
     */
    @ApiOperation("查询流水")
    @RequestMapping(value = "/getFlowList", method = RequestMethod.POST)
    @ResponseBody
    CommonResponse<List<FlowVO>> getFlowList(@RequestBody QueryParam queryParam) {
        List<FlowEntity> flowEntityList = flowService.queryList(queryParam);
        List<FlowVO> flowVOS = BeanMapper.mapList(flowEntityList, FlowVO.class);
        return CommonResponse.success(flowVOS);
    }

    @ApiOperation("查询流水")
    @RequestMapping(value = "/getFlowPage", method = RequestMethod.POST)
    @ResponseBody
    CommonResponse<IPage<FlowVO>> getFlowPage(@RequestBody QueryParam queryParam) {
        IPage<FlowEntity> page = flowService.queryPage(queryParam, false);
        IPage<FlowVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
        pageData.setRecords(BeanMapper.mapList(page.getRecords(), FlowVO.class));
        return CommonResponse.success("查询列表数据成功！", pageData);
    }


    /**
     * @param queryParam
     * @description: 查询出入库关系
     * @return: com.ejianc.framework.core.response.CommonResponse<com.ejianc.business.store.vo.InOutVO>
     * @author 姜轶凯
     * @date: 2022/3/15
     */
    @RequestMapping(value = "/getInOutVOList", method = RequestMethod.POST)
    @ResponseBody
    CommonResponse<List<InOutVO>> getInOutVOList(@RequestBody QueryParam queryParam){
        List<InOutEntity> inOutEntities = inOutService.queryList(queryParam);
        List<InOutVO> inOutVOS = BeanMapper.mapList(inOutEntities, InOutVO.class);
        return CommonResponse.success(inOutVOS);
    }

    @RequestMapping(value = "/getNewPrice", method = RequestMethod.POST)
    @ResponseBody
    CommonResponse<List<FlowVO>> getNewPrice(@RequestBody List<FlowVO> flowVOS){
        List<FlowVO> result = new ArrayList<>();
        for (FlowVO flowVO : flowVOS) {
            QueryWrapper<FlowEntity> wrapper = new QueryWrapper();
            wrapper.eq("store_id", flowVO.getStoreId());
            wrapper.eq("material_id", flowVO.getMaterialId());
            wrapper.eq("brand_id", flowVO.getBrandId());
            wrapper.eq("in_out_flag", StoreCommonConsts.IN_OUT_TYPE_IN);
            wrapper.orderByDesc( "source_bill_date");
            wrapper.last("limit 0,1");
            List<FlowEntity> flowEntities = flowService.list(wrapper);
            if (CollectionUtils.isNotEmpty(flowEntities)) {
                result.add(BeanMapper.map(flowEntities.get(0), FlowVO.class));
            }
        }
        return CommonResponse.success("查询最新单价成功！", result);
    }

    /**
     * 批量获取最新的库存余量
     * @param surplusVOS
     * @return
     */
    @RequestMapping(value = "/getNewSurplusNum", method = RequestMethod.POST)
    @ResponseBody
    CommonResponse<List<SurplusVO>> getNewSurplusNum(@RequestBody List<SurplusVO> surplusVOS){
        QueryWrapper<SurplusEntity> queryWrapper = new QueryWrapper<>();
        queryWrapper.and(q -> {
            for(SurplusVO f : surplusVOS) {
                q.or(iq -> iq.eq("store_id", f.getStoreId()).eq("brand_id", f.getBrandId()).eq("material_id", f.getMaterialId()));
            }
            return q;
        });
        List<SurplusEntity> list = surplusService.list(queryWrapper);
        List<SurplusVO> result = null;
        if (CollectionUtils.isNotEmpty(list)) {
            result = BeanMapper.mapList(list, SurplusVO.class);
            for (SurplusVO surplusVO : result) {
                surplusVO.setSurplusTaxPrice(ComputeUtil.safeDiv(surplusVO.getSurplusTaxMny(), surplusVO.getSurplusNum()));
                surplusVO.setSurplusPrice(ComputeUtil.safeDiv(surplusVO.getSurplusMny(), surplusVO.getSurplusNum()));
                surplusVO.setSurplusNum(ComputeUtil.safeSub(surplusVO.getSurplusNum(), surplusVO.getIdleNum()));
            }
        }
        return CommonResponse.success("批量获取最新的库存余量成功！", result);
    }

    /**
     * 根据仓库查询库存参照
     * @param storeId
     * @return
     */
    @RequestMapping(value = "/refSurplusData", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<List<SurplusVO>> refSurplusData(@RequestParam("storeId") Long storeId) {
        QueryParam param = new QueryParam();
        /** 租户隔离 */
        param.getParams().put("storeId", new Parameter(QueryParam.EQ, storeId));
        //库存可用数量大于0
        param.getParams().put("surplusNum", new Parameter(QueryParam.SQL, "(IFNULL(surplus_num,0)-IFNULL(idle_num,0))>0"));
        param.getOrderMap().clear();
        param.getOrderMap().put("abs(ifnull(surplus_num,0)-ifnull(idle_num,0))", "desc");

        List<SurplusEntity> list = surplusService.queryList(param, false);
        List<SurplusVO> surplusVOS = BeanMapper.mapList(list, SurplusVO.class);
        surplusVOS.forEach(
                t -> {
                    t.setSurplusHasOutLockNum(ComputeUtil.safeAdd(t.getSurplusNum(), t.getOutLockNum()));
                    t.setSurplusMny(ComputeUtil.safeAdd(t.getSurplusMny(), t.getOutLockMny()));
                    t.setSurplusTaxMny(ComputeUtil.safeAdd(t.getSurplusTaxMny(), t.getOutLockTaxMny()));
                    t.setSurplusNum(ComputeUtil.safeSub(t.getSurplusNum(), t.getIdleNum()));
                }
        );
        return CommonResponse.success("查询参照数据成功！", surplusVOS);
    }
}
